@@ -37,7 +37,7 @@ Interacts
 """
 
 from traitlets import (Bool, Int, Float, Unicode, Dict,
-                       Instance, List, Enum)
+                       Instance, List, Enum, observe)
 from traittypes import Array
 from ipywidgets import Widget, Color, widget_serialization, register
 
@@ -45,6 +45,7 @@ from .scales import Scale, DateScale
 from .traits import Date, array_serialization
 from .marks import Lines
 from ._version import __frontend_version__
+import numpy as np
 
 
 def register_interaction(key=None):
@@ -389,8 +390,8 @@ class BrushSelector(TwoDSelector):
         in terms of the y_scale of the selector.
         This attribute changes while the selection is being made with the
         ``BrushSelector``.
-    selected: list
-        Readonly 2x2 array containing the coordinates 
+    selected: numpy.ndarray
+        A 2x2 array containing the coordinates 
         [[selected_x[0], selected_y[0]],
          [selected_x[1], selected_y[1]]]
     brushing: bool (default: False)
@@ -406,16 +407,37 @@ class BrushSelector(TwoDSelector):
     brushing = Bool().tag(sync=True)
     selected_x = Array(None, allow_none=True).tag(sync=True, **array_serialization)
     selected_y = Array(None, allow_none=True).tag(sync=True, **array_serialization)
+    selected = Array(None, allow_none=True)
     color = Color(None, allow_none=True).tag(sync=True)
 
-    # This is for backward compatibility
-    @property
-    def selected(self):
-        if self.selected_x is None or len(self.selected_x) == 0:
-            return []
+    # This is for backward compatibility for code that relied on selected
+    # instead of select_x and selected_y
+    @observe('selected_x', 'selected_y')
+    def _set_selected(self, change):
+        if self.selected_x is None or len(self.selected_x) == 0 or \
+           self.selected_y is None or len(self.selected_y) == 0:
+            self.selected = None
         else:
-            return [[self.selected_x[0], self.selected_y[0]],
-                    [self.selected_x[1], self.selected_y[1]]]
+            self.selected = np.array([[self.selected_x[0], self.selected_y[0]],
+                             [self.selected_x[1], self.selected_y[1]]])
+
+    @observe('selected')
+    def _set_selected_xy(self, change):
+        value = self.selected
+        if self.selected is None or len(self.selected) == 0:
+            # if we set either selected_x OR selected_y to None
+            # we don't want to set the other to None as well
+            if not (self.selected_x is None or len(self.selected_x) == 0
+                 or self.selected_y is None or len(self.selected_y) == 0):
+                self.selected_x = None
+                self.selected_y = None
+        else:
+            (x0, y0), (x1, y1) = value
+            x = [x0, x1]
+            y = [y0, y1]
+            with self.hold_sync():
+                self.selected_x = x
+                self.selected_y = y
 
     _view_name = Unicode('BrushSelector').tag(sync=True)
     _model_name = Unicode('BrushSelectorModel').tag(sync=True)
